@@ -1,7 +1,7 @@
 "gstat" <-
 function (g, id, formula, locations, data = NULL, model = NULL, 
     beta, nmax = Inf, maxdist = Inf, dummy = FALSE, set, fill.all = FALSE,
-	variance = "identity") 
+	variance = "identity", weights = NULL) 
 {
 	if (fill.all) {
 		if (missing(g) || is.null(model))
@@ -42,7 +42,7 @@ function (g, id, formula, locations, data = NULL, model = NULL,
         stop("argument locations should be of class formula")
     if (missing(beta) || is.null(beta)) 
         beta = numeric(0)
-	vfn = pmatch(variance, c("identity", "mu", "mu(1-mu)"))
+	vfn = pmatch(variance, c("identity", "mu", "mu(1-mu)", "mu^2", "mu^3"))
 	if (is.na(vfn))
 		stop("unknown value for variance function")
 	if (vfn > 1 && length(beta) == 0)
@@ -55,9 +55,9 @@ function (g, id, formula, locations, data = NULL, model = NULL,
     if (missing(id)) 
         id = paste("var", length(g$data) + 1, sep = "")
     g$data[[id]] = list(formula = formula, locations = locations, 
-        	data = data, has.intercept = attr(terms(formula), "intercept"),
+        data = data, has.intercept = attr(terms(formula), "intercept"),
 		beta = beta, nmax = nmax, maxdist = maxdist, dummy = dummy,
-		vfn = vfn)
+		vfn = vfn, weights = weights)
     g$model[[id]] = model
     if (!missing(set)) {
         if (!is.list(set)) 
