@@ -9,8 +9,6 @@ function (formula, locations, data)
     }
     call = match.call()
     X = model.matrix(delete.resp.f(formula), data = data)
-    if (nrow(X) == 1 && nrow(data) > 1) 
-        X = as.matrix(rep(X, nrow(data)))
     m = match.call(expand = FALSE)
     m$method = m$model = m$x = m$y = m$... = NULL
     m$formula = m$locations
@@ -21,5 +19,7 @@ function (formula, locations, data)
     attr(Terms, "intercept") = 0
     # locations = model.matrix(locations, data = data)
     locations = model.matrix(Terms, m)
+    if (nrow(X) == 1 && nrow(locations) > 1) 
+        X = as.matrix(rep(X, nrow(locations)))
     list(locations = locations, X = X, call = call)
 }
