@@ -19,5 +19,5 @@ function(x, y, z, zero = 0.0)
 	index <- 1:(n*n)
 	z <- index[as.vector(D) <= zero]
 	ret <- cbind(((z - 1)  %/% n) + 1, ifelse(z %% n == 0, n, z %% n))
-	ret[ret[,1] < ret[,2], ]
+	matrix(ret[ret[,1] < ret[,2],], ncol = 2)
 }
