@@ -40,6 +40,8 @@
 #include "userio.h"
 #include "debug.h"
 #include "vario.h"
+#include "sem.h"
+#include "fit.h"
 #include "glvars.h"
 #include "lm.h"
 #include "gls.h"
@@ -51,7 +53,11 @@
 #include "getest.h"
 
 static void est_quantile_div(DATA *data, double *est, int div);
+static void est_skew_kurt(DATA *data, double *est);
 static double inverse_dist(DATA *data, DPOINT *where, double idPow);
+static void save_variogram_parameters(VARIOGRAM *v);
+static void reset_variogram_parameters(VARIOGRAM *v);
+static double *vgm_pars = NULL;
 
 static void calc_poly(DPOINT *where, double *est);
 
@@ -64,6 +70,7 @@ void get_est(DATA **data, METHOD method, DPOINT *where, double *est) {
  * USES: several estimation routines.
  */
 	DPOINT *block = NULL;
+	VARIOGRAM *v;
 	int i, j, n_vars, n_sel, *is_pt;
 	static GRIDMAP **m = NULL;
 	unsigned int row = 0, col = 0;
@@ -105,12 +112,20 @@ void get_est(DATA **data, METHOD method, DPOINT *where, double *est) {
 			printlog("stratum: %d\n", where->u.stratum);
 	}
 	switch (method) {
-		case MED : 
+		case DIV: /* BREAKTHROUGH */
+		case MED: 
 			if (get_mode() == STRATIFY)
-				est_quantile_div(data[where->u.stratum], est, 0);
+				est_quantile_div(data[where->u.stratum], est, method == DIV);
 			else
 				for (i = 0; i < n_vars; i++)
-					est_quantile_div(data[i], &(est[2*i]), 0);
+					est_quantile_div(data[i], &(est[2*i]), method == DIV);
+			break;
+		case SKEW: 
+			if (get_mode() == STRATIFY)
+				est_skew_kurt(data[where->u.stratum], est);
+			else
+				for (i = 0; i < n_vars; i++)
+					est_skew_kurt(data[i], &(est[2*i]));
 			break;
 		case IDW: 
 			if (gl_idp < 0.0)
@@ -327,9 +342,8 @@ void get_est(DATA **data, METHOD method, DPOINT *where, double *est) {
 					pr_warning("define more (dummy) points(..) to get all masks");
 				m = (GRIDMAP **) emalloc(get_n_masks() * sizeof(GRIDMAP *));
 				for (i = 0; i < get_n_masks(); i++) {
-					m[i] = new_map();
+					m[i] = new_map(READ_ONLY);
 					m[i]->filename = string_dup(get_mask_name(i));
-					m[i]->is_write = 0;
 					if (map_read(m[i]) == NULL)
 						ErrMsg(ER_READ, get_mask_name(i));
 				}
@@ -379,12 +393,32 @@ void get_est(DATA **data, METHOD method, DPOINT *where, double *est) {
 				}
 			}
 			break;
-		case DIV : 
-			if (get_mode() == STRATIFY)
-				est_quantile_div(data[where->u.stratum], est, 1);
-			else
-				for (i = 0; i < n_vars; i++)
-					est_quantile_div(data[i], &(est[2*i]), 1);
+		case LSEM:
+			v = get_vgm(LTI(0,0));
+			assert(v);
+			v->id1 = v->id2 = v->id = 0;
+			v->ev->evt = SEMIVARIOGRAM;
+			v->ev->recalc = 1;
+			calc_variogram(v, NULL);
+			if (gl_fit) { 
+				v->ev->refit = 1;
+				v->ev->fit = gl_fit;
+				save_variogram_parameters(v);
+				fit_variogram(v);
+				/* write back locally fitted variogram model parameters: */
+				for (i = 0; i < MIN(get_n_vars(), v->n_models); i++) {
+					est[2 * i + 0] = v->part[i].sill;
+					est[2 * i + 1] = v->part[i].range[0];
+				}
+				reset_variogram_parameters(v);
+				update_variogram(v); /* not sure if this is needed */
+			} else {
+				/* write back locally estimated sample variogram values: */
+				for (i = 0; i < MIN(get_n_vars(), v->ev->n_est); i++) {
+					est[2 * i + 0] = v->ev->gamma[i];
+					est[2 * i + 1] = 1.0 * v->ev->nh[i];
+				}
+			}
 			break;
 		case NSP:  /* FALLTRHOUGH: */
 		default: 
@@ -398,28 +432,30 @@ void get_est(DATA **data, METHOD method, DPOINT *where, double *est) {
 static void est_quantile_div(DATA *data, double *est, int div) {
 	static double *list = NULL;
 	static int i, size = 0;
-	int n;
+	double mod = -9999.0;
+	int n, run, longest_run = 0;
 
 	if (data->n_sel > size) 
 		list = (double *) erealloc(list, (size = data->n_sel) * sizeof(double));
 	for (i = 0; i < data->n_sel; i++)
 		list[i] = data->sel[i]->attr;
 	qsort(list, (size_t) data->n_sel, sizeof(double),
-		(int 
-#ifdef SPLUS6WIN32
-		__cdecl
-#endif
-		 (*)(const void *, const void *)) d_cmp);
-	if (div) { /* get diversity and range in sel: */
+		(int CDECL (*)(const void *, const void *)) d_cmp);
+	if (div) { /* get diversity and modus in sel: */
 		n = data->n_sel;
-		for (i = 0; i < data->n_sel - 1; i++)
-			if (list[i] == list[i+1])
+		for (i = 0; i < data->n_sel - 2; i += run) {
+			run = 1;
+			while (i + run < data->n_sel && list[i] == list[i + run]) {
+				run++;
 				n--;
+			}
+			if (run > longest_run) {
+				longest_run = run;
+				mod = list[i];
+			}
+		}
 		est[0] = 1.0 * n;
-		if (data->n_sel > 0)
-			est[1] = list[data->n_sel - 1] - list[0];
-		else
-			set_mv_double(est+1);
+		est[1] = mod;
 	} else {
 		if (data->n_sel < 2)
 			return;
@@ -433,6 +469,26 @@ static void est_quantile_div(DATA *data, double *est, int div) {
 	return;
 }
 
+static void est_skew_kurt(DATA *data, double *est) {
+	static double *list = NULL;
+	double mean, std, skewness = 0.0, kurtosis = 0.0, d;
+	static int i, size = 0;
+
+	if (data->n_sel > size) 
+		list = (double *) erealloc(list, (size = data->n_sel) * sizeof(double));
+	for (i = 0; i < data->n_sel; i++)
+		list[i] = data->sel[i]->attr;
+	mean = sample_mean(list, data->n_sel);
+	std = sample_std(list, mean, data->n_sel);
+	for (i = 0; i < data->n_sel; i++) {
+			d = (data->sel[i]->attr - mean)/std;
+			skewness += pow(d, 3.0);
+			kurtosis += pow(d, 4.0);
+	}
+	est[0] = skewness/data->n_sel;
+	est[1] = kurtosis/data->n_sel;
+}
+
 static double inverse_dist(DATA *data, DPOINT *where, double idPow) {
 	int i, j;
 	double sumweights, sumvals, value, weight, dist2;
@@ -467,9 +523,9 @@ static void calc_poly(DPOINT *where, double *est) {
 	int j, k;
 	
 
-	int n=get_n_edges();
-    POLYGON **edges=get_edges();
-    int *n_edges_polys=get_n_edges_polys();
+	int n = get_n_edges();
+    POLYGON **edges = get_edges();
+    int *n_edges_polys = get_n_edges_polys();
 
     pt.x = where->x;
     pt.y = where->y;
@@ -484,3 +540,24 @@ static void calc_poly(DPOINT *where, double *est) {
 		}
 	}
 }
+
+void save_variogram_parameters(VARIOGRAM *v) {
+	int i;
+	if (vgm_pars == NULL)
+		vgm_pars = (double *) emalloc(3 * v->n_models * sizeof(double));
+	for (i = 0; i < v->n_models; i++) {
+		vgm_pars[3 * i + 0] = v->part[i].sill;
+		vgm_pars[3 * i + 1] = v->part[i].range[0];
+		vgm_pars[3 * i + 2] = v->part[i].range[1];
+	}
+
+}
+
+void reset_variogram_parameters(VARIOGRAM *v) {
+	int i;
+	for (i = 0; i < v->n_models; i++) {
+		v->part[i].sill = vgm_pars[3 * i + 0];
+		v->part[i].range[0] = vgm_pars[3 * i + 1];
+		v->part[i].range[1] = vgm_pars[3 * i + 2];
+	}
+}
