@@ -59,6 +59,15 @@ TODO:
 		    # ix = loc - (iz-1)nx.ny-(iy-1)nx
 */
 
+/* 
+ * if (gl_rowwise != 0), no complete map is not kept in memory.
+ * take care that the complete map should be blanked (RputAllMV())
+ * before writing takes place, when applying this method to other
+ * formats (e.g. GDAL), as map_set_row() is only applied to WRITE_ONLY
+ * maps for rows that contain non-missing valued cells!
+ * SECOND: WRITE_ONLY maps should be open in read-write (r+) state!!
+ * */
+
 #include <stdio.h>
 #include <math.h>				/* floor() */
 #include <float.h>				/* FLT_MAX */
@@ -81,7 +90,7 @@ TODO:
 # include "glvars.h"
 #else							/* standalone version: */
 # include "defaults.h"
-int debug_level = 1, gl_secure = 0;
+int debug_level = 1, gl_secure = 0, gl_rowwise = 1;
 double gl_zero = DEF_zero;
 char *gl_mv_string = "NA";
 #endif
@@ -119,6 +128,8 @@ static GRIDMAP *write_T2(GRIDMAP * m);
 static GRIDMAP *read_csf(GRIDMAP * m);
 static GRIDMAP *write_csf(GRIDMAP * m);
 static GRIDMAP *dup_csf(GRIDMAP * m, GRIDMAP * dup);
+void CsfReadRow(GRIDMAP *m, float *buf, unsigned int row);
+void CsfWriteRow(GRIDMAP *m, float *buf, unsigned int row);
 #endif
 
 #ifdef HAVE_LIBNETCDF
@@ -129,6 +140,13 @@ static int cdf_read_grd_info(GRIDMAP * m, double *x_max, double *y_min,
 							 int *node_offset);
 #endif
 
+#ifdef HAVE_LIBGDAL
+#include "gdal.h"
+#include "cpl_error.h"
+static GRIDMAP *read_gdal(GRIDMAP * m);
+static GRIDMAP *write_gdal(GRIDMAP * m);
+#endif
+
 #ifdef HAVE_LIBGIS
 static GRIDMAP *read_grass(GRIDMAP * m);
 static GRIDMAP *write_grass(GRIDMAP * m);
@@ -154,6 +172,8 @@ static void swap_floats(unsigned char *b, unsigned int n);
 static void swap_multiformat(unsigned char *b, unsigned int m,
 							 unsigned int n);
 static unsigned int sizeof_ct(CellType ct);
+static void alloc_mv_grid(GRIDMAP * m);
+static void map_set_row(GRIDMAP *m, unsigned int row);
 
 static float default_misval_idrisi = 0.0;
 
@@ -184,11 +204,12 @@ static char *er_projection = NULL;
  * allocates memory and initializes all fields for a GRIDMAP structure
  * returns: pointer to GRIDMAP structure
  */
-GRIDMAP *new_map(void)
+GRIDMAP *new_map(MAP_READ_STATUS status)
 {
 	GRIDMAP *map;
 
 	map = (GRIDMAP *) emalloc(sizeof(GRIDMAP));
+	map->status = status;
 	map->type = MT_UNKNOWN;
 	map->history = NULL;
 	map->description = NULL;
@@ -198,20 +219,82 @@ GRIDMAP *new_map(void)
 	map->base_size = 0;
 	map->grid = NULL;
 	map->base = NULL;
-	map->is_write = 0;
+	map->first_time_row = NULL;
 	map->is_binary = 0;
 	map->celltype = CT_UNKNOWN;
 	map->misval = DEFAULT_MISVAL;	/* only for arcgrid */
 	map->cellmin = map->cellmax = FLT_MAX;
 	map->CSF_MAP = NULL;
+#ifdef HAVE_LIBGDAL
+	map->GeoTransform = (double *) emalloc(6 * sizeof(double));
+#endif
 	map->write = write_error;
+	map->read_row = map->write_row = NULL;
+	map->current_row = 0;
 	return map;
 }
 
+static void map_set_row(GRIDMAP *m, unsigned int new_row)
+{
+	int start = 0, i;
+
+	if (m->status == READ_ONLY && m->read_row == NULL)
+		return;
+	if (m->status == WRITE_ONLY && m->write_row == NULL)
+		return;
+
+	if (m->grid == NULL) {
+		m->grid = (float **) emalloc(m->rows * sizeof(float *));
+		m->first_time_row = (unsigned int *) emalloc(m->rows * 
+					sizeof(unsigned int));
+		m->current_row = 0;
+		m->grid[0] = (float *) emalloc(m->cols * sizeof(float));
+		memset(m->grid[0], 0xFF, m->cols * sizeof(float));
+		for (i = 1; i < m->rows; i++) {
+			m->grid[i] = NULL;
+			m->first_time_row[i] = 1;
+		}
+		start = 1;
+	}
+
+	assert(m->grid[m->current_row] != NULL);
+	assert(new_row >= 0 && new_row < m->rows);
+
+	switch (m->status) {
+		case READ_ONLY:
+			if (m->current_row != new_row || start)
+				m->read_row(m, m->grid[m->current_row], new_row);
+			break;
+		case WRITE_ONLY:
+			if (new_row != m->current_row) { /* flush old row to disk: */
+				m->write_row(m, m->grid[m->current_row], m->current_row);
+				if (m->first_time_row[new_row]) {
+					memset(m->grid[m->current_row], 0xFF, 
+							m->cols * sizeof(float));
+					m->first_time_row[new_row] = 0;
+				} else { /* been here before: re-read the written content: */
+					m->read_row(m, m->grid[m->current_row], new_row);
+					/* adjust this pointer to [new_row] a few lines down: */
+				}
+			}
+			break;
+		default:
+			ErrMsg(ER_IMPOSVAL, "unknown switch");
+			break;
+	}
+	/* now adjust buffer pointer; */
+	if (new_row != m->current_row) { 
+		m->grid[new_row] = m->grid[m->current_row];
+		m->grid[m->current_row] = NULL;
+		m->current_row = new_row;
+	}
+	assert(m->grid[m->current_row] != NULL);
+}
+
 /*
  * read in a grid map and fill all necessary fields;
- * at least m->filename and m->is_write should be filled before
- * returns: a pointer to a GRIDMAP read, NULL in case the map is not
+ * at least m->filename should be filled before returns: 
+ * a pointer to a GRIDMAP read, NULL in case the map is not
  * one of the formats supported.
  */
 GRIDMAP *map_read(GRIDMAP * m)
@@ -219,7 +302,7 @@ GRIDMAP *map_read(GRIDMAP * m)
 
 	assert(m);
 	assert(m->filename);
-	assert(!m->is_write);
+	assert(m->status == READ_ONLY);
 
 #ifdef HAVE_LIBGIS /* try grass: */
 	if (read_grass(m))
@@ -254,7 +337,7 @@ GRIDMAP *map_read(GRIDMAP * m)
 		return m;
 	DUMP("no\n")
 
-		/* try ARCGRID */
+	/* try ARCGRID */
 	if (read_arcgrid(m))
 		return m;
 	DUMP("no\n");
@@ -277,27 +360,34 @@ GRIDMAP *map_read(GRIDMAP * m)
 	DUMP("no\n");
 #endif
 
+#ifdef HAVE_LIBGDAL /* try gdal: */
+	if (read_gdal(m))
+		return m;
+	DUMP("no\n")
+#endif
+
 	/* no success: */
 	return NULL;
 }
 
 static GRIDMAP *write_error(GRIDMAP * m)
 {
-	pr_warning("%s: map format was not supplied", m->filename);
+	pr_warning("%s: writing this map format is not supported", m->filename);
 	assert(0);
 	return NULL;
 }
 
-void alloc_mv_grid(GRIDMAP * m)
+static void alloc_mv_grid(GRIDMAP * m)
 {
 	unsigned int i;
 
-	m->grid = (float **) emalloc(m->rows * sizeof(float *));
 	m->base_size = m->rows * m->cols;
 	m->base = (float *) emalloc(m->base_size * sizeof(float));
-	for (i = 0; i < m->rows; i++)
-		m->grid[i] = &(m->base[i * m->cols]);
 	memset(m->base, 0xFF, m->base_size * sizeof(float));
+
+	m->grid = (float **) emalloc(m->rows * sizeof(float *));
+	for (i = 0; i < m->rows; i++) /* set up handles: */
+		m->grid[i] = &(m->base[i * m->cols]);
 }
 
 /*
@@ -373,9 +463,9 @@ int map_cell_is_mv(GRIDMAP * m /* pointer to map */ ,
 				   unsigned int row /* row number */ ,
 				   unsigned int col /* column number */ )
 {
-
 	assert(m);
 	assert(row < m->rows && col < m->cols);
+	map_set_row(m, row);
 
 	return is_mv_float(&(m->grid[row][col]));
 }
@@ -391,6 +481,7 @@ float map_get_cell(GRIDMAP * m /* pointer to GRIDMAP */ ,
 {
 	assert(m);
 	assert(row < m->rows && col < m->cols);
+	map_set_row(m, row);
 	assert(!is_mv_float(&(m->grid[row][col])));
 
 	return m->grid[row][col];
@@ -402,13 +493,15 @@ float map_get_cell(GRIDMAP * m /* pointer to GRIDMAP */ ,
  * returns: 0
  */
 int map_put_cell(GRIDMAP * m,	/* pointer to GRIDMAP structure */
-				 unsigned int row,	/* row number */
-				 unsigned int col,	/* column number */
-				 float value /* cell value to write */ )
+		 unsigned int row,	/* row number */
+		 unsigned int col,	/* column number */
+		 float value /* cell value to write */ )
 {
 	assert(m);
 	assert(row < m->rows && col < m->cols);
 
+	map_set_row(m, row);
+
 	m->grid[row][col] = value;
 	if (m->cellmin == FLT_MAX)
 		m->cellmin = m->cellmax = value;
@@ -432,13 +525,20 @@ GRIDMAP *map_dup(const char *fname, GRIDMAP * m)
 	assert(m);
 	assert(fname);
 
-	dup = new_map();
-	*dup = *m;					/* copy all fields */
+	dup = new_map(WRITE_ONLY);
+	*dup = *m;					/* copy all fields; incl status */
+#ifdef HAVE_LIBGDAL
+	dup->GeoTransform = memcpy(emalloc(6 * sizeof(double)), m->GeoTransform,		6 * sizeof(double));
+#endif
 	dup->cellmin = dup->cellmax = FLT_MAX;	/* re-initialize */
 	dup->CSF_MAP = NULL;		/* copying would only cause trouble! */
-	alloc_mv_grid(dup);
 	dup->filename = string_dup(fname);
-	dup->is_write = 1;
+	dup->status = WRITE_ONLY;
+	dup->current_row = 0;
+	if (dup->write_row == NULL) /* do the whole block in memory */
+		alloc_mv_grid(dup);
+	else
+		dup->grid = NULL;
 #ifdef HAVE_LIBCSF
 	if (dup->type == MT_CSF && (dup = dup_csf(m, dup)) == NULL)
 		ErrMsg(ER_WRITE, fname);
@@ -1250,13 +1350,17 @@ static GRIDMAP *read_csf(GRIDMAP * m)
 		RgetMinVal(m_tmp, &(m->cellmin));
 		RgetMaxVal(m_tmp, &(m->cellmax));
 		m->type = MT_CSF;
-		alloc_mv_grid(m);
-		if (RgetSomeCells(m_tmp, 0, m->base_size, m->base) != m->base_size)
-			ErrMsg(ER_READ, m->filename);
+
+		if (gl_rowwise) {
+			m->read_row = CsfReadRow;
+			m->write_row = CsfWriteRow;
+		} else {
+			alloc_mv_grid(m);
+			if (RgetSomeCells(m_tmp, 0, m->base_size, m->base) != m->base_size)
+				ErrMsg(ER_READ, m->filename);
+		}
+
 		m->CSF_MAP = (void *) m_tmp;
-		/* TRY ----------------------------
-		   Mclose(m->CSF_MAP);
-		 */
 		m->write = write_csf;
 		DUMP("yes\n");
 		return m;
@@ -1267,13 +1371,15 @@ static GRIDMAP *read_csf(GRIDMAP * m)
 
 static GRIDMAP *write_csf(GRIDMAP * m)
 {
-	unsigned int i;
-
 	if (m->CSF_MAP == NULL)
 		ErrMsg(ER_NULL, "write_csf()");
-	i = RputSomeCells((MAP *) m->CSF_MAP, 0, m->base_size, m->base);
-	if (i != m->base_size)
-		ErrMsg(ER_WRITE, m->filename);
+	if (m->write_row != NULL) /* flush last row: */
+		m->write_row(m, m->grid[m->current_row], m->current_row);
+	else { /* flush complete map: */
+		if (RputSomeCells((MAP *) m->CSF_MAP, 0, m->base_size, m->base) != 
+						m->base_size)
+			ErrMsg(ER_WRITE, m->filename);
+	}
 	if (m->history)
 		MputHistory((MAP *) m->CSF_MAP, m->history);	/* full history */
 	if (m->description)
@@ -1287,27 +1393,45 @@ static GRIDMAP *write_csf(GRIDMAP * m)
 	return m;
 }
 
+void CsfReadRow(GRIDMAP *m, float *buf, unsigned int row)
+{
+	if (RgetRow(m->CSF_MAP, row, buf) != m->cols)
+		ErrMsg(ER_READ, m->filename);
+}
+
+void CsfWriteRow(GRIDMAP *m, float *buf, unsigned int row)
+{
+	if (RputRow(m->CSF_MAP, row, buf) != m->cols)
+		ErrMsg(ER_READ, m->filename);
+}
+
 static GRIDMAP *dup_csf(GRIDMAP * m, GRIDMAP * dup)
 {
 
 	if (m->CSF_MAP != NULL) {	/* use csf duplicate routines: */
-		if ((dup->CSF_MAP = Rdup(dup->filename, (MAP *) m->CSF_MAP,
-								 (dup->celltype ==
-								  CT_UINT8 ? CR_UINT1 : CR_REAL4),
-								 VS_SCALAR)) == NULL) {
-			Mperror(dup->filename);
-			return NULL;
+		if (dup->celltype == CT_UINT8) {
+			if ((dup->CSF_MAP = Rdup(dup->filename, (MAP *) m->CSF_MAP,
+					CR_UINT1, VS_NOMINAL)) == NULL) {
+				ErrMsg(ER_WRITE, dup->filename);
+				return NULL;
+			}
+		} else {
+			if ((dup->CSF_MAP = Rdup(dup->filename, (MAP *) m->CSF_MAP,
+					CR_REAL4, VS_SCALAR)) == NULL) {
+				ErrMsg(ER_WRITE, dup->filename);
+				return NULL;
+			}
 		}
-		if (dup->celltype == CT_UINT8
-			&& RuseAs(dup->CSF_MAP, CR_REAL4) != 0) ErrMsg(ER_IMPOSVAL,
-														   "cannot use map as REAL4");
+		if (dup->celltype == CT_UINT8 && RuseAs(dup->CSF_MAP, CR_REAL4)) 
+				ErrMsg(ER_IMPOSVAL, "cannot use map as REAL4");
 	} else {					/* convert, i.e. create: */
-		dup->CSF_MAP =
-			Rcreate(dup->filename, dup->rows, dup->cols, CR_REAL4,
-					VS_SCALAR, PT_YDECT2B, dup->x_ul, dup->y_ul, 0.0,
-					dup->cellsizex);
+		dup->CSF_MAP = Rcreate(dup->filename, dup->rows, dup->cols, CR_REAL4,
+				VS_SCALAR, PT_YDECT2B, dup->x_ul, dup->y_ul, 0.0,
+				dup->cellsizex);
 		set_mv_float(&(dup->misval));
 	}
+	if (gl_rowwise)
+		RputAllMV(dup->CSF_MAP);
 	return dup;
 }
 #endif
@@ -1331,7 +1455,10 @@ static GRIDMAP *read_grass(GRIDMAP * m)
 
 	name = (char *) m->filename;
 	if ((mapset = G_find_cell2(name, "")) == NULL)
+		return NULL;
+		/*
 		G_fatal_error("%s: <%s> cellfile not found\n", G_program_name(), name);
+		*/
 
 	map_type = G_raster_map_type(name, mapset);
 	out_type = map_type;
@@ -1384,9 +1511,10 @@ static GRIDMAP *read_grass(GRIDMAP * m)
 				if (out_type == CELL_TYPE)
 					map_put_cell(m, row, col, (int) *((CELL *) ptr));
 				else if (out_type == FCELL_TYPE)
-					map_put_cell(m, row, col, *((FCELL *) ptr));
-				else if (out_type == DCELL_TYPE)
-					map_put_cell(m, row, col, (double) *((FCELL *) ptr));
+					map_put_cell(m, row, col, (float) *((FCELL *) ptr));
+				else if (out_type == DCELL_TYPE) {
+					map_put_cell(m, row, col, (double) *((DCELL *) ptr));
+				}
 			}
 		}						/* for col */
 	}							/* for row */
@@ -1394,7 +1522,6 @@ static GRIDMAP *read_grass(GRIDMAP * m)
 	m->write = write_grass;
 	m->type = MT_GRASS;
 	m->is_binary = 1;
-	m->is_write = 0;
 	m->celltype = CT_IEEE4;
 	return m;
 }
@@ -1517,6 +1644,147 @@ static GRIDMAP *write_grass(GRIDMAP * m)
 
 #endif
 
+#ifdef HAVE_LIBGDAL
+static GRIDMAP *read_gdal(GRIDMAP *m) {
+	double adfMinMax[2];
+	int i, j, bGotMin, bGotMax;
+	GDALRasterBandH  hBand;
+
+	/* GDALAllRegister(); -- has been done in main() */
+	DUMP(m->filename);
+	DUMP(": trying one of GDAL formats... ");
+
+	CPLPushErrorHandler(CPLQuietErrorHandler);
+	if ((m->hDataset = GDALOpen(m->filename, GA_ReadOnly)) == NULL)
+		return NULL;
+	CPLErrorReset();
+	CPLPopErrorHandler();
+
+	DUMP("yes!\n");
+	m->hDriver = GDALGetDatasetDriver(m->hDataset);
+	if (DEBUG_NORMAL)
+		printlog( "GDAL driver: %s [%s]\n", 
+			GDALGetDriverShortName(m->hDriver),
+			GDALGetDriverLongName(m->hDriver));
+
+	if (GDALGetRasterCount(m->hDataset) > 1)
+		pr_warning("only band 1 in %s is used", m->filename);
+
+	if (GDALGetProjectionRef(m->hDataset) != NULL && DEBUG_NORMAL) 
+		printlog("Projection is `%s'\n", GDALGetProjectionRef(m->hDataset));
+
+	if (GDALGetGeoTransform(m->hDataset, m->GeoTransform) == CE_None) {
+		if (DEBUG_NORMAL) {
+			printlog("Origin = (%g,%g), ",
+				m->GeoTransform[0], m->GeoTransform[3]);
+			printlog("Pixel Size = (%g,%g), ",
+				m->GeoTransform[1], m->GeoTransform[5]);
+		}
+		m->x_ul = m->GeoTransform[0];
+		m->y_ul = m->GeoTransform[3];
+		m->cellsizex = fabs(m->GeoTransform[1]);
+		m->cellsizey = fabs(m->GeoTransform[5]); 
+		/* funny, but may be neg.!! */
+		/* 
+		printf("cellsize: %g x %g\n", m->cellsizex, m->cellsizey);
+		*/
+	} else
+		ErrMsg(ER_IMPOSVAL, "no GDALGetGeoTransform information");
+
+	hBand = GDALGetRasterBand(m->hDataset, 1);
+	adfMinMax[0] = GDALGetRasterMinimum(hBand, &bGotMin);
+	adfMinMax[1] = GDALGetRasterMaximum(hBand, &bGotMax);
+	if(! (bGotMin && bGotMax))
+	    GDALComputeRasterMinMax( hBand, TRUE, adfMinMax );
+
+	if (DEBUG_NORMAL)
+		printlog( "Min=%g, Max=%g\n", adfMinMax[0], adfMinMax[1] );
+	m->cellmin = adfMinMax[0];
+	m->cellmax = adfMinMax[1];
+	
+	if(GDALGetOverviewCount(hBand) > 0 && DEBUG_DUMP)
+	    printlog( "Band has %d overviews.\n", GDALGetOverviewCount(hBand));
+
+	if(GDALGetRasterColorTable( hBand ) != NULL && DEBUG_DUMP)
+	    printf("Band has a color table with %d entries.\n", 
+		     GDALGetColorEntryCount(GDALGetRasterColorTable(hBand)));
+
+	m->rows = GDALGetRasterBandYSize(hBand);
+	m->cols = GDALGetRasterBandXSize(hBand);
+	alloc_mv_grid(m);
+	m->misval = GDALGetRasterNoDataValue(hBand, NULL);
+	for (i = 0; i < m->rows; i++) {
+		if (GDALRasterIO(hBand, GF_Read, 0, i, m->cols, 1, 
+			m->grid[i], m->cols, 1, GDT_Float32, 
+			0, 0 ) == CE_Failure)
+				pr_warning("error on reading %s\n", m->filename);
+		for (j = 0; j < m->cols; j++)
+			if (m->grid[i][j] == m->misval)
+				set_mv_float(&(m->grid[i][j]));
+	}
+	m->type = MT_GDAL;
+	m->is_binary = 1; /* not necessarily */
+	m->celltype = CT_IEEE4;
+	/* 
+	GDALClose(m->hDataset);
+	*/
+	m->write = write_gdal;
+	return m;
+}
+
+static GRIDMAP *write_gdal(GRIDMAP *m) {
+	/* NOTE this function still fails on anything */
+	GDALRasterBandH  hBand;
+	int i, j;
+	unsigned char b;
+
+	CPLPushErrorHandler(CPLQuietErrorHandler);
+	if ((m->hDataset = GDALCreate(m->hDriver, m->filename, m->cols, m->rows, 1, 
+			m->celltype == CT_UINT8 ? GDT_Byte : GDT_Float32, NULL)) == NULL) {
+		CPLPopErrorHandler();
+		CPLErrorReset();
+		pr_warning("GDAL cannot write this format; using asciigrid for %s", 
+			m->filename);
+		m->is_binary = 0;
+		write_arcgrid(m);
+		return m;
+	} 
+	CPLPopErrorHandler();
+	if (GDALSetGeoTransform(m->hDataset, m->GeoTransform) != CE_None)
+		ErrMsg(ER_IMPOSVAL, "cannot set GDALGetGeoTransform information");
+
+	hBand = GDALGetRasterBand(m->hDataset, 1);
+	if (m->celltype != CT_UINT8) {
+		GDALSetRasterNoDataValue(hBand, m->misval);
+		for (i = 0; i < m->rows; i++) { /* one row at a time */
+			for (j = 0; j < m->cols; j++)
+				if (is_mv_float(&(m->grid[i][j])))
+					m->grid[i][j] = m->misval;
+			if (GDALRasterIO(hBand, GF_Write, 0, i, m->cols, 1, 
+				m->grid[i], m->cols, 1, GDT_Float32, 
+				0, 0 ) == CE_Failure)
+					pr_warning("error on writing %s\n", m->filename);
+		}
+	} else {
+		GDALSetRasterNoDataValue(hBand, (double) 0xFF);
+		for (i = 0; i < m->rows; i++) {
+			for (j = 0; j < m->cols; j++) {
+				if (is_mv_float(&(m->grid[i][j])))
+					b = 0xFF;
+				else
+					b = (unsigned char) m->grid[i][j];
+				if (GDALRasterIO(hBand, GF_Write, j, i, 1, 1, 
+					&b, sizeof(unsigned char), 1, GDT_Byte, 
+					0, 0) == CE_Failure)
+						pr_warning("error on writing %s\n", m->filename);
+				}
+		}
+	}
+	GDALClose(m->hDataset);
+	return m;
+}
+#endif
+
 #ifdef HAVE_LIBNETCDF
 # include "netcdf.h"
 /* Macro to create a NaN */
@@ -2580,8 +2848,7 @@ static GRIDMAP *read_gslib(GRIDMAP * m)
 	if (siz[2] > 0.0)
 		pr_warning("z-dimension of GSLIB grid (%g) will be lost", siz[2]);
 
-
-	m = new_map();
+	m = new_map(READ_ONLY);
 	m->cols = n[0];
 	m->rows = n[1];
 	m->x_ul = min[0] - 0.5 * siz[0];
@@ -2636,7 +2903,7 @@ static GRIDMAP *write_gslib(GRIDMAP * m)
 	return m;
 }
 
-GRIDMAP *map_switch_type(GRIDMAP * in, MAPTYPE type) {
+GRIDMAP *map_switch_type(GRIDMAP *in, MAPTYPE type) {
 
 	switch (type) {
 	case MT_ARCGRID:
@@ -2693,6 +2960,11 @@ GRIDMAP *map_switch_type(GRIDMAP * in, MAPTYPE type) {
 #ifdef HAVE_T2_GRIDFORMAT
 		in->is_binary = 0;
 		in->write = write_T2;
+#endif
+		break;
+	case MT_GDAL:
+#ifdef HAVE_LIBGDAL
+		in->write = write_gdal;
 #endif
 		break;
 	case MT_UNKNOWN:
