@@ -47,11 +47,7 @@
 static int octant_select(DATA *d, DPOINT *where);
 static int which_octant(DPOINT *where, DPOINT *p, int mode);
 
-int 
-#ifdef SPLUS6WIN32
-	__cdecl
-#endif
-	dist_cmp(const DPOINT **ap, const DPOINT **bp);
+int CDECL dist_cmp(const DPOINT **ap, const DPOINT **bp);
 static void zero_sel_dist2(DATA *d);
 static void print_selection(DATA *d, DPOINT *where);
 
@@ -131,17 +127,13 @@ int select_at(DATA *d, DPOINT *where) {
 	memcpy(d->sel, d->list, d->n_list * sizeof(DPOINT *));
 	if (d->sel_rad >= DBL_MAX && d->sel_max >= d->n_list && d->oct_max == 0) {
 		if (get_n_edges()) {
-			d->n_sel = d->n_list;
 			zero_sel_dist2(d);
 			check_edges(d, where);
-			if (DEBUG_SEL) 
-				print_selection(d, where);
-			return d->n_sel;
-		} else {
-			if (DEBUG_SEL) 
-				print_selection(d, where);
-			return (d->n_sel = d->n_list);
-		}
+		} 
+		d->n_sel = d->n_list;
+		if (DEBUG_SEL) 
+			print_selection(d, where);
+		return d->n_sel;
 	}
 
 /*
@@ -161,30 +153,25 @@ int select_at(DATA *d, DPOINT *where) {
  * Now, should we select further, sorting on distance?
  */
 
-	if (d->vdist) /* use variogram distance as sort criterium */
+	if (d->vdist) { /* use variogram distance as sort criterium */
 		for (i = 0; i < d->n_sel; i++)
 			d->sel[i]->u.dist2 = get_semivariance(get_vgm(LTI(d->id,d->id)),
 				where->x - d->sel[i]->x,
 				where->y - d->sel[i]->y,
 				where->z - d->sel[i]->z);
+	}
 
 	if (d->oct_max) { /* do octant selection */
 		d->oct_filled = octant_select(d, where);
 		/* sorts, adjusts n_sel and destroys distance order, so only */
 		if (get_method() == SPREAD) /* then we've got to re-order them */
 			qsort(d->sel, (size_t) d->n_sel, sizeof(DPOINT *), (int
-#ifdef SPLUS6WIN32
-				__cdecl
-#endif
-				(*)(const void *,const void *)) dist_cmp);
+				CDECL (*)(const void *,const void *)) dist_cmp);
 	} 
 
 	if (d->vdist) {
 		qsort(d->sel, (size_t) d->n_sel, sizeof(DPOINT *), (int 
-#ifdef SPLUS6WIN32
-			__cdecl
-#endif
-			(*)(const void *, const void *)) dist_cmp);
+			CDECL (*)(const void *, const void *)) dist_cmp);
 		/* pick d->sel_[max|min] nearest: */
 		if (d->sel_min && d->n_sel == d->sel_min
 				&& d->sel[d->n_sel]->u.dist2 > d->sel_rad) /* we forced: */
@@ -227,11 +214,8 @@ static int octant_select(DATA *d, DPOINT *where) {
 			n_notempty++; /* Yahoo, another non-empty octant! */
 		if (n > d->oct_max) {
 			/* to get the closest n: sort sel from start to end: */
-			qsort(sel + start, (size_t) n, sizeof(DPOINT *), (int 
-#ifdef SPLUS6WIN32
-				__cdecl
-#endif
-				(*)(const void *, const void *)) dist_cmp);
+			qsort(sel + start, (size_t) n, sizeof(DPOINT *), 
+				(int CDECL (*)(const void *, const void *)) dist_cmp);
 			/* swap the remaining ones to the end of sel and forget about'm: */
 			for (j = start + d->oct_max; j < end; j++) {
 				d->n_sel--;
@@ -274,11 +258,7 @@ static int which_octant(DPOINT *where, DPOINT *p, int mode) {
 	return (x | (y << 1) | (z << 2));	
 }
 
-int 
-#ifdef SPLUS6WIN32
-__cdecl
-#endif
-dist_cmp(const DPOINT **pa, const DPOINT **pb) {
+int CDECL dist_cmp(const DPOINT **pa, const DPOINT **pb) {
 /* ANSI qsort() conformant dist_cmp */
 
 	if ( (*pa)->u.dist2 < (*pb)->u.dist2 )
